%define pkg       haproxy
%define ver       1.6.11
%define maj       %(echo %{ver} | cut -d'.' -f1)
%define min       %(echo %{ver} | cut -d'.' -f2)
%define pkg_str   %{pkg}%{maj}%{min}


Summary:          A TCP/HTTP reverse proxy for high availability environments
Name:             %{pkg_str}
Version:          %{ver}
Release:          1%{?dist}%{?pext}
License:          GPLv2+
Group:            System Environment/Daemons
Source0:          http://www.%{pkg}.org/download/1.6/src/%{pkg}-%{ver}.tar.gz
Source1:          %{pkg}.init
Source2:          %{pkg}.sysconfig
Source3:          %{pkg}.logrotate
Source4:          %{pkg}.conf
Patch0:           %{pkg}-1.6.2-build_lua.patch
Patch1:           %{pkg}-1.5.14-contrib_halog.patch
URL:              http://www.%{pkg}.org/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           Willy Tarreau <w@1wt.eu>
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    lua53-devel openssl10-devel pcre-devel
BuildRequires:    zlib-devel
BuildArch:        i486 x86_64


%description
HAProxy is a free, very fast and reliable solution offering high availability,
load balancing, and proxying for TCP and HTTP-based applications. It is parti-
cularly suited for very high traffic web sites and powers quite a number of the
world's most visited ones. Over the years it has become the de-facto standard
open-source load balancer, is now shipped with most mainstream distributions,
and is often deployed by default in cloud platforms.


%prep
%setup -q -n %{pkg}-%{ver}
%patch0 -p1
%patch1 -p1


%build
%{__make} %{?_smp_mflags}           \
	CC="%{__cc}"                \
	ADDINC="${RPM_OPT_FLAGS}"   \
	CPU="generic"               \
	TARGET="linux26"            \
	USE_GETADDRINFO=1           \
	USE_LINUX_TPROXY=1          \
%ifarch %ix86 x86_64
	USE_REGPARM=1               \
%endif
	USE_LUA=1                   \
	USE_PCRE=1                  \
	USE_OPENSSL=1               \
	USE_ZLIB=1

for TOOL in halog iprange ip6range; do
  pushd contrib/${TOOL}
  %{__make} %{?_smp_mflags}         \
	OPTIMIZE="${RPM_OPT_FLAGS}" \
	${TOOL}
  popd
done


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{logrotate.d,sysconfig,%{pkg}}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_bindir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/%{pkg}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{pkg}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	PREFIX=%{_prefix}         \
	install-bin install-man

%{__install} -m 0755 %{SOURCE1}   ${RPM_BUILD_ROOT}%{_initrddir}/%{pkg}
%{__install} -m 0644 %{SOURCE2}   ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{pkg}
%{__install} -m 0644 %{SOURCE3}   ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{pkg}

%{__install} -m 0640 %{SOURCE4}   ${RPM_BUILD_ROOT}%{_sysconfdir}/%{pkg}/%{pkg}.cfg

for TOOL in halog iprange ip6range; do
  pushd contrib/${TOOL}
  %{__install} -m 0755 ${TOOL}    ${RPM_BUILD_ROOT}%{_bindir}
  %{__install} -m 0644 ${TOOL}.1  ${RPM_BUILD_ROOT}%{_mandir}/man1 2>/dev/null || :
  popd
done

pushd examples
%{__install} -m 0644 errorfiles/* ${RPM_BUILD_ROOT}%{_datadir}/%{pkg}
popd

# Cleanup
%{__rm}      -f                   ${RPM_BUILD_ROOT}%{_sbindir}/%{pkg}-systemd-wrapper


%pre
if ! getent group  %{pkg} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 188 %{pkg}
fi
if ! getent passwd %{pkg} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 188 -g %{pkg} \
	-d %{_localstatedir}/lib/%{pkg}  \
	-c "HAProxy Service user" -M     \
	-s /sbin/nologin %{pkg}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{pkg}


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{pkg} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{pkg}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{pkg} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc CHANGELOG CONTRIBUTING LICENSE MAINTAINERS
%doc README ROADMAP doc/*.{fig,txt}
%doc --parents examples/*.{cfg,sh,vim}
%attr(750,root,%{pkg}) %dir %{_sysconfdir}/%{pkg}
%attr(640,root,%{pkg}) %config(noreplace) %{_sysconfdir}/%{pkg}/%{pkg}.cfg
%{_initrddir}/%{pkg}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{pkg}
%config(noreplace) %{_sysconfdir}/sysconfig/%{pkg}
%{_bindir}/halog
%{_bindir}/iprange
%{_bindir}/ip6range
%{_sbindir}/%{pkg}
%config(noreplace) %{_datadir}/%{pkg}
%{_mandir}/man1/*.1*
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/lib/%{pkg}


%changelog
* Thu Jan 12 2017 Peter Pramberger <peterpramb@member.fsf.org> - 1.6.11-1
- Initial build
